"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useContextApolloClient = exports.ApolloClientsManager = exports.ApolloClientsContext = void 0;
var react_1 = require("react");
/**
 * React context to hold ApolloClientsManager instance
 */
exports.ApolloClientsContext = react_1.createContext(null);
/**
 * Used as the IoC container to inject Apollo client instances into components
 * based on their names
 */
var ApolloClientsManager = /** @class */ (function () {
    function ApolloClientsManager(clients) {
        this.clients = clients;
    }
    ApolloClientsManager.prototype.getClient = function (key) {
        if (key === void 0) { key = 'default'; }
        return this.clients[key];
    };
    ApolloClientsManager.prototype.extract = function () {
        var result = {};
        for (var _i = 0, _a = Object.entries(this.clients); _i < _a.length; _i++) {
            var _b = _a[_i], key = _b[0], value = _b[1];
            result[key] = value.extract();
        }
        return result;
    };
    return ApolloClientsManager;
}());
exports.ApolloClientsManager = ApolloClientsManager;
/**
 * Injects Apollo client from the context based on the provided name or
 * uses the provided instance. If called without arguments, uses the default
 * instance
 *
 * @param clientOrName - name of the Apollo client to be injected, or instance to be used
 */
function useContextApolloClient(clientOrName) {
    var apolloClientsContext = react_1.useContext(exports.ApolloClientsContext);
    if (!clientOrName || typeof clientOrName === 'string') {
        if (!apolloClientsContext) {
            throw new Error("ApolloClientsContext is not provided");
        }
        var client = !clientOrName ? apolloClientsContext.getClient() : apolloClientsContext.getClient(clientOrName);
        if (!client) {
            throw new Error("ApolloClient '" + clientOrName + "' is not registered in the ApolloClientsContext");
        }
        return client;
    }
    return clientOrName;
}
exports.useContextApolloClient = useContextApolloClient;
//# sourceMappingURL=ApolloClientsContext.js.map