import { UseAsyncOperationOptions } from '@proscom/prostore-react';
import ApolloClient, { MutationOptions, OperationVariables } from 'apollo-client';
/**
 * Allows to observe status of the GraphQL-mutation
 * @param clientOrName - ApolloClient instance to be used for data fetching, or its name for it to be injected from the context
 * @param options - Options are passed to ApolloClient's `mutate` method
 * @param hookOptions - Options are passed to useAsyncOperation hook
 * @returns [run, loading], where
 *  - `run` is the callback which accepts partial options which are passed to ApolloClient's `mutate` method
 *  - `loading` is the current state whether the async operation is running
 * @example
 *  const [run, loading] = useGraphqlMutation(null, { mutation: MUTATION });
 *  return <div>{loading ? 'Loading...' : <button onClick={() => run({ variables: { time: new Date() } })} />}
 */
export declare function useGraphqlMutation<Result = any, Variables = OperationVariables>(clientOrName?: string | ApolloClient<any> | null | undefined, options?: Partial<MutationOptions<Result, Variables>>, hookOptions?: UseAsyncOperationOptions): {
    run: (mutationOptions: Partial<MutationOptions<Result, Variables>>) => Promise<import("apollo-link").FetchResult<Result, Record<string, any>, Record<string, any>>>;
    loading: boolean;
    finished: boolean;
    setFinished: (finished: boolean) => void;
};
