import { __assign } from "tslib";
import { useAsyncOperation } from '@proscom/prostore-react';
import { useContextApolloClient } from './ApolloClientsContext';
/**
 * Allows to observe status of the GraphQL-mutation
 * @param clientOrName - ApolloClient instance to be used for data fetching, or its name for it to be injected from the context
 * @param options - Options are passed to ApolloClient's `mutate` method
 * @param hookOptions - Options are passed to useAsyncOperation hook
 * @returns [run, loading], where
 *  - `run` is the callback which accepts partial options which are passed to ApolloClient's `mutate` method
 *  - `loading` is the current state whether the async operation is running
 * @example
 *  const [run, loading] = useGraphqlMutation(null, { mutation: MUTATION });
 *  return <div>{loading ? 'Loading...' : <button onClick={() => run({ variables: { time: new Date() } })} />}
 */
export function useGraphqlMutation(clientOrName, options, hookOptions) {
    if (clientOrName === void 0) { clientOrName = null; }
    if (options === void 0) { options = {}; }
    if (hookOptions === void 0) { hookOptions = {}; }
    var client = useContextApolloClient(clientOrName);
    return useAsyncOperation(function (mutationOptions) {
        return client.mutate(__assign(__assign({}, options), mutationOptions));
    }, hookOptions);
}
//# sourceMappingURL=useGraphqlMutation.js.map