import { DependencyList } from 'react';
import { GraphqlQueryStore, IGraphqlQueryOptions, IGraphqlQueryStoreParams } from '@proscom/prostore-apollo';
import { UseRequestOptions } from '@proscom/prostore-react';
import { ApolloClient } from 'apollo-client';
import { PartialKey } from '@proscom/prostore';
export declare type IUseGraphqlQueryOptions<Vars, Data> = PartialKey<IGraphqlQueryStoreParams<Vars, Data>, 'client'>;
export interface IUseGraphqlQueryParams<Vars, Data> {
    /** Apollo Client instance to be used for data fetching, or its name for it to be injected from the context */
    client?: string | ApolloClient<any>;
    /** Query specification */
    queryOptions: IUseGraphqlQueryOptions<Vars, Data>;
    /** Query variables */
    variables?: Vars;
    /** Additional query options */
    options?: IGraphqlQueryOptions<Vars, Data>;
    /** Additional hook options */
    hookOptions?: UseRequestOptions<Vars, Data>;
}
/**
 * Creates GraphqlQueryStore and subscribes to it using useRequestStore.
 * Effectively this requests data from the apollo based on the provided variables and queryOptions
 *
 * @returns {{load, check, state}} - Current request state
 */
export declare function useGraphqlQuery<Vars, Data>({ client, queryOptions, variables, options, hookOptions }: IUseGraphqlQueryParams<Vars, Data>): import("@proscom/prostore-react").UseRequestStoreResult<GraphqlQueryStore<Vars, Data>>;
export interface IUseGraphQueryVarsParams<Vars, Data> extends IUseGraphqlQueryParams<Vars, Data> {
    variableCreator: [() => Vars, DependencyList];
}
/**
 * The same as useGraphqlQuery, but it uses variableCreator which is supplied to useMemo and
 * can be used to memoize query variables. This may be used when the default behavior of deeply
 * comparing variables is not preferable (i.e., it is not fast enough, or variables are not simple objects)
 *
 * @returns {{load, check, state}} - Current request state
 * @deprecated This function is not needed since useGraphqlQuery performs deep equality check
 * on variables
 */
export declare function useGraphqlQueryVars<Vars, Data>({ variableCreator, ...queryProps }: IUseGraphQueryVarsParams<Vars, Data>): import("@proscom/prostore-react").UseRequestStoreResult<GraphqlQueryStore<Vars, Data>>;
