import { __assign, __rest } from "tslib";
import { useContext, useMemo } from 'react';
import { GraphqlWatchQueryStore } from '@proscom/prostore-apollo';
import { ProstoreSsrContext, useRequestStore } from '@proscom/prostore-react';
import { useContextApolloClient } from './ApolloClientsContext';
/**
 * Creates GraphqlWatchQueryStore and subscribes to it using useRequestStore.
 * Effectively this requests data from the apollo based on the provided variables and queryOptions
 *
 * @returns {{load, check, state}} - Current request state
 */
export function useGraphqlWatchQuery(_a) {
    var client = _a.client, queryOptions = _a.queryOptions, variables = _a.variables, options = _a.options, hookOptions = _a.hookOptions;
    var actualClient = useContextApolloClient(client);
    var ssrContext = useContext(ProstoreSsrContext);
    var store = useMemo(function () {
        return new GraphqlWatchQueryStore(__assign({ ssrContext: ssrContext, client: actualClient }, queryOptions));
    }, [ssrContext, actualClient, queryOptions]);
    return useRequestStore(store, variables, options, hookOptions);
}
/**
 * The same as useGraphqlWatchQuery, but it uses variableCreator which is supplied to useMemo and
 * can be used to memoize query variables. This may be used when the default behavior of deeply
 * comparing variables is not preferable (i.e., it is not fast enough, or variables are not simple objects)
 *
 * @returns {{load, check, state}} - Current request state
 * @deprecated This function is not needed since useGraphqlWatchQuery performs deep equality check
 * on variables
 */
export function useGraphqlWatchQueryVars(_a) {
    var variableCreator = _a.variableCreator, queryProps = __rest(_a, ["variableCreator"]);
    var variables = useMemo.apply(void 0, variableCreator);
    return useGraphqlWatchQuery(__assign(__assign({}, queryProps), { variables: variables }));
}
//# sourceMappingURL=useGraphqlWatchQuery.js.map