"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useGraphqlMutation = void 0;
var tslib_1 = require("tslib");
var prostore_react_1 = require("@proscom/prostore-react");
var ApolloClientsContext_1 = require("./ApolloClientsContext");
/**
 * Allows to observe status of the GraphQL-mutation
 * @param clientOrName - ApolloClient instance to be used for data fetching, or its name for it to be injected from the context
 * @param options - Options are passed to ApolloClient's `mutate` method
 * @param hookOptions - Options are passed to useAsyncOperation hook
 * @returns [run, loading], where
 *  - `run` is the callback which accepts partial options which are passed to ApolloClient's `mutate` method
 *  - `loading` is the current state whether the async operation is running
 * @example
 *  const [run, loading] = useGraphqlMutation(null, { mutation: MUTATION });
 *  return <div>{loading ? 'Loading...' : <button onClick={() => run({ variables: { time: new Date() } })} />}
 */
function useGraphqlMutation(clientOrName, options, hookOptions) {
    if (clientOrName === void 0) { clientOrName = null; }
    if (options === void 0) { options = {}; }
    if (hookOptions === void 0) { hookOptions = {}; }
    var client = ApolloClientsContext_1.useContextApolloClient(clientOrName);
    return prostore_react_1.useAsyncOperation(function (mutationOptions) {
        return client.mutate(tslib_1.__assign(tslib_1.__assign({}, options), mutationOptions));
    }, hookOptions);
}
exports.useGraphqlMutation = useGraphqlMutation;
//# sourceMappingURL=useGraphqlMutation.js.map